@@ -1,7 +1,9 @@
-import string, array
+import array
+import string
 
 legal_dna = "ACGTN"
 
+
 def is_DNA(seq):
     """
     Returns 1 if it contains only legal values for a DNA sequence.
@@ -14,11 +16,12 @@ def is_DNA(seq):
 
     return 1
 
+
 def reverse_complement(s):
     """
     Build reverse complement of 's'.
     """
-    s = string.upper(s)
+    s = s.upper()
     assert is_DNA(s), "Your sequence must be DNA!"
 
     r = reverse(s)
@@ -26,23 +29,27 @@ def reverse_complement(s):
 
     return rc
 
+
 rc = reverse_complement                 # alias 'rc' to 'reverse_complement'
 
-__complementTranslation = string.maketrans('ACTG', 'TGAC')
+try:
+    __complementTranslation = str.maketrans('ACTG', 'TGAC')
+except AttributeError:
+    __complementTranslation = string.maketrans('ACTG', 'TGAC')
+
 
 def complement(s):
     """
     Return complement of 's'.
     """
-    c = string.translate(s, __complementTranslation)
+    c = s.translate(__complementTranslation)
     return c
 
+
 def reverse(s):
     """
     Return reverse of 's'.
     """
-    r = array.array('c', s)
-    r.reverse()
-    r = string.join(r, '')
+    r = "".join(reversed(s))
 
     return r
