@@ -1,4 +1,7 @@
-import DBConstants
+from __future__ import absolute_import
+
+from . import DBConstants
+from .utils import to_str
 
 FieldTypes = (('hava', DBConstants._INDEXED_TEXT_KEY),
               ('quarzk', DBConstants._STANDARD_TEXT),
@@ -14,14 +17,14 @@ def hava_iter(handle):
     is a handle to a file opened for reading
     """
     data = {}
-    line = handle.readline().strip()
+    line = to_str(handle.readline().strip())
     while line:
         data['hava'] = line
-        data['quarzk'] = handle.readline().strip()
-        data['muchalo'] = handle.readline().strip()
-        data['fakours'] = handle.readline().strip()
-        data['selimizicka'] = handle.readline().strip()
-        data['marshoon'] = handle.readline().strip()
-        
-        line = handle.readline().strip()
+        data['quarzk'] = to_str(handle.readline().strip())
+        data['muchalo'] = to_str(handle.readline().strip())
+        data['fakours'] = to_str(handle.readline().strip())
+        data['selimizicka'] = to_str(handle.readline().strip())
+        data['marshoon'] = to_str(handle.readline().strip())
+
+        line = to_str(handle.readline().strip())
         yield data
